/**
 * Copyright Kyndryl, Inc. 2022
 */
import { LitElement } from 'lit';
/**
 * AccordionItem component. *
 * @fires on-toggle - Emits the `opened` state when the accordion item opens/closes.
 * @slot icon - Optional leading icon
 * @slot body - Body of the accordion item
 * @slot title - Title of the accordion item
 * @slot subtitle - Optional subtitle of the accordion item
 *
 */
export declare class AccordionItem extends LitElement {
    static styles: import("lit").CSSResultGroup[];
    /** Accordion item opened state. */
    opened: boolean;
    /** Accordion item disabled state. */
    disabled: boolean;
    /**
     * The index of this item. Passed from the Accordion.
     * @ignore
     */
    private _index;
    /**
     * Whether the number should be shown. Passed from the Accordion.
     * @ignore
     */
    private _showNumber;
    /**
     * Whether this item displays a filled header. Passed from the Accordion.
     * @ignore
     */
    private _filledHeader;
    /**
     * Whether this item is compact. Passed from the Accordion.
     * @ignore
     */
    private _compact;
    setIndex(index: number): void;
    setShowNumbers(value: boolean): void;
    setFilledHeader(value: boolean): void;
    setCompact(value: boolean): void;
    open(): void;
    close(): void;
    private _handleClick;
    private _handleKeypress;
    private _toggleOpenState;
    private _emitToggleEvent;
    /**
     * Generates the number template
     * @ignore
     */
    get numberTemplate(): import("lit-html").TemplateResult<1> | "";
    /**
     * Generates the icon template
     * @ignore
     */
    get iconTemplate(): import("lit-html").TemplateResult<1> | "";
    /**
     * Generates the subtitle template
     * @ignore
     */
    get subtitleTemplate(): import("lit-html").TemplateResult<1> | "";
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'kd-accordion-item': AccordionItem;
    }
}
//# sourceMappingURL=accordionItem.d.ts.map