/**
 * Copyright Kyndryl, Inc. 2023
 */
import { LitElement } from 'lit';
import { BUTTON_KINDS, BUTTON_SIZES, BUTTON_TYPES, BUTTON_ICON_POSITION } from './defs';
/**
 * Button component.
 *
 * @slot unnamed - Slot for button text.
 * @slot icon - Slot for an icon.
 * @fires on-click - Emits the original click event.
 */
export declare class Button extends LitElement {
    static styles: import("lit").CSSResultGroup[];
    /** @ignore */
    static shadowRootOptions: {
        delegatesFocus: boolean;
        mode: ShadowRootMode;
        slotAssignment?: SlotAssignmentMode | undefined;
    };
    /**
     * Associate the component with forms.
     * @ignore
     */
    static formAssociated: boolean;
    /**
     * Attached internals for form association.
     * @ignore
     */
    internals: ElementInternals;
    /** ARIA label for the button for accessibility. */
    description: string;
    /** Type for the &lt;button&gt; element. */
    type: BUTTON_TYPES;
    /** Specifies the visual appearance/kind of the button. */
    kind: BUTTON_KINDS;
    /** Converts the button to an &lt;a&gt; tag if specified. */
    href: string;
    /** Specifies the size of the button. */
    size: BUTTON_SIZES;
    /** Specifies the position of the icon relative to any button text. */
    iconPosition: BUTTON_ICON_POSITION;
    /** Determines if the button is disabled.
     * @internal
     */
    iconOnly: boolean;
    /** Determines if the button is disabled. */
    disabled: boolean;
    /** Determines if the button indicates a destructive action. */
    destructive: boolean;
    /** Button value.  */
    value: string;
    /** Button name. */
    name: string;
    /** Determines if the button is Floatable */
    isFloating: boolean;
    /** Show button after scrolling to 50% of the page*/
    showOnScroll: boolean;
    /** Determines showButton state .
     * @internal
     */
    _showButton: boolean;
    /** re-size button to 'medium' at mobile breakpoint.
     * @internal
     */
    _reSizeBtn: boolean;
    /** Button formmethod.  */
    formmethod: any;
    /** Queries default slot nodes.
     * @internal
     */
    _slottedEls: Array<any>;
    /** Queries icon slot nodes.
     * @internal
     */
    _iconEls: Array<any>;
    /** Queries the .button element.
     * @internal
     */
    _btnEl: any;
    render(): import("lit-html").TemplateResult<1>;
    private handleClick;
    private _testIconOnly;
    private _handleSlotChange;
    /** @internal */
    private _debounceResize;
    /** @internal */
    private _reSizeButton;
    /** @internal */
    private _debounceScroll;
    /** @internal */
    private _handleScroll;
    connectedCallback(): void;
    disconnectedCallback(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'kd-button': Button;
    }
}
//# sourceMappingURL=button.d.ts.map