import { LitElement } from 'lit';
/**
 * Card.
 * @fires on-card-click - Captures the click event of clickable card and emits the original event details. Use `e.stopPropogation()` / `e.preventDefault()` for any internal clickable elements when card type is `'clickable'` to stop bubbling / prevent event.
 * @slot unnamed - Slot for card contents.
 */
export declare class Card extends LitElement {
    static styles: import("lit").CSSResultGroup;
    /** Card Type. `'normal'` & `'clickable'` */
    type: string;
    /** Card link url for clickable cards. */
    href: string;
    /** Use for Card type `'clickable'`. Defines a relationship between a linked resource and the document. An empty string (default) means no particular relationship. */
    rel: string;
    /** Defines a target attribute for where to load the URL in case of clickable card. Possible options include `'_self'` (deafult), `'_blank'`, `'_parent`', `'_top'` */
    target: any;
    /** Hide card border. Useful when clickable card use inside `<kyn-notification>` component. */
    hideBorder: boolean;
    render(): import("lit-html").TemplateResult<1>;
    private handleClick;
}
declare global {
    interface HTMLElementTagNameMap {
        'kd-card': Card;
    }
}
//# sourceMappingURL=card.d.ts.map